import { baseRequest, request } from '../request';

/** get role list */
export function fetchGetRoleList(params?: Api.SystemManage.RoleSearchParams) {
  return baseRequest<Api.SystemManage.RoleList>({
    url: '/api/v1/role',
    method: 'get',
    params
  });
}
// 改变角色状态
export function fetchChangeRoleStatus(data?: Api.SystemManage.ChangeRoleStatusParams) {
  return baseRequest<Api.SystemManage.RoleList>({
    url: '/api/v1/role-status',
    method: 'put',
    data
  });
}
// 根据角色ID查询菜单权限下拉树结构 /** get menu tree */
export function fetchGetMenuTree(roleId: number) {
  return baseRequest({
    url: `/api/v1/roleMenuTreeselect/${roleId}`,
    method: 'get'
  });
}
/**
 * get all roles
 *
 * these roles are all enabled
 */
export function fetchGetAllRoles(params: any) {
  return baseRequest({
    url: '/api/v1/role',
    method: 'get',
    params
  });
}
// 根据角色来获取配置的menu 菜单
export function fetchGetMenuIdsByRole(roleId: number) {
  return baseRequest({
    url: `/api/v1/role/${roleId}`,
    method: 'get'
  });
}
// 新增角色
export function fetchAddRole(data: any) {
  return baseRequest({
    url: '/api/v1/role',
    method: 'post',
    data
  });
}
// 修改角色
export function fetchEditRole(data: any, roleId: number) {
  return baseRequest({
    url: `/api/v1/role/${roleId}`,
    method: 'put',
    data
  });
}
// 删除角色
export function fetchDeleteRole(data: any) {
  return baseRequest({
    url: '/api/v1/role',
    method: 'delete',
    data
  });
}
// 修改角色的权限范围
export function fetchModifyRolePersion(data: any) {
  return baseRequest({
    url: '/api/v1/roledatascope',
    method: 'put',
    data
  });
}
// 根据角色ID查询部门树结构
export function fetchDeptTreeByRole(roleId: number) {
  return baseRequest({
    url: `/api/v1/roleDeptTreeselect/${roleId}`,
    method: 'get'
  });
}
/** get user list */
export function fetchGetUserList(params?: Api.SystemManage.UserSearchParams) {
  return baseRequest<Api.SystemManage.UserList>({
    url: '/api/v1/sys-user',
    method: 'get',
    params
  });
}

/** get menu list */
export function fetchGetMenuList(params?: Api.SystemManage.MenuSearchParams) {
  return baseRequest<Api.SystemManage.MenuList>({
    url: '/api/v1/menu',
    method: 'get',
    params
  });
}
// 添加菜单
export function fetchAddMenu(data: any) {
  return baseRequest<Api.SystemManage.MenuList>({
    url: '/api/v1/menu',
    method: 'post',
    data
  });
}
// 修改菜单
export function fetchUpdateMenu(data: any, id: number) {
  return baseRequest({
    url: `/api/v1/menu/${id}`,
    method: 'put',
    data
  });
}
// 删除菜单
export function fetchDeleteMenu(data: any) {
  return baseRequest({
    url: '/api/v1/menu',
    method: 'delete',
    data
  });
}

// 查询菜单详情
export function fetchGetMenuDetail(menuId: number) {
  return baseRequest({
    url: `/api/v1/menu/${menuId}`,
    method: 'get'
  });
}

// 获取api权限列表
export function fetchGetSysApiList(data: any) {
  return baseRequest({
    url: '/api/v1/sys-api',
    method: 'get',
    params: data
  });
}

/** get all pages */
export function fetchGetAllPages() {
  return request<string[]>({
    url: '/systemManage/getAllPages',
    method: 'get'
  });
}

// 根据字典类型查询字典数据信息
export function getDicts(dictType: string) {
  return baseRequest({
    url: `/api/v1/dict-data/option-select?dictType=${dictType}`,
    method: 'get'
  });
}
// 岗位
export function fetchGetPostList(params: any) {
  return baseRequest({
    url: '/api/v1/post',
    method: 'get',
    params
  });
}
// 查询部门下拉树结构
export function fetchGetdeptTreeList() {
  return baseRequest({
    url: '/api/v1/deptTree',
    method: 'get'
  });
}
// 新增用户
export function fetchAddUser(data: any, method: string) {
  return baseRequest({
    url: '/api/v1/sys-user',
    method,
    data
  });
}
// 删除用户
export function fetchDelteUser(data: any) {
  return baseRequest({
    url: '/api/v1/sys-user',
    method: 'delete',
    data
  });
}
// 重置密码
export function fetchRestPwsUser(data: any) {
  return baseRequest({
    url: '/api/v1/user/pwd/reset',
    method: 'put',
    data
  });
}
// 用户状态修改
export function changeUserStatus(data: any) {
  return baseRequest({
    url: '/api/v1/user/status',
    method: 'put',
    data
  });
}

// 获取部门列表
export function fetchDeptList(params?: Api.SystemManage.UserSearchParams) {
  return baseRequest<Api.SystemManage.UserList>({
    url: '/api/v1/dept',
    method: 'get',
    params
  });
}
