import type { ElegantConstRoute, LastLevelRouteKey } from '@elegant-router/types';

interface DataItem {
  name: string;
  path: string;
  component: string;
  title: string;
  icon: string;
  sort: number;
  children?: DataItem[];
  visible: string;
}

function replacePath(val: string) {
  return val.slice(1).replace('/index', '').replace('/', '_');
}
function getTransComponent(item: DataItem, level: number): string {
  const { component: name, children } = item;
  let isChildren = true;
  if (!children || children?.length === 0) {
    isChildren = false;
  }
  if (level === 0 && !isChildren) {
    return `layout.base$view.${replacePath(name)}`;
  } else if (name === 'Layout') {
    return 'layout.base';
  }
  const newVal = replacePath(name);
  return `view.${newVal}`;
}
function getTransComponentName(val: string) {
  const newVal = replacePath(val);
  return newVal;
}

function transData(menus: DataItem[], level: number = 0): ElegantConstRoute[] {
  return menus.map(item => {
    const obj: ElegantConstRoute = {
      name: getTransComponentName(item.path),
      path: item.path,
      component: getTransComponent(item, level),
      meta: {
        title: item.title,
        order: item.sort,
        localIcon: item.icon,
        _level: level,
        hideInMenu: item.visible === '1'
      },
      children: []
    };
    if (Array.isArray(item.children)) {
      obj.children = transData(item.children, level + 1);
    }
    return obj;
  });
}

export function transformToTargetData(data: DataItem[]): {
  routes: ElegantConstRoute[];
  home: LastLevelRouteKey;
} {
  return { routes: transData(data), home: 'new-home' };
}
